==> members-facade-1.0.2-20190530.085957-101-sources.jar: com/bizvane/members/facade/models/po/MbrChatTimePO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrChatTimePO implements Serializable {

	/**
	 * 只读. 主键. mbr_chat_time
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "主键", name = "mbrChatTime", required = false, example = "")
	private Long mbrChatTime;
	/**
	 * 只读. . sys_company_id
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. . brand_id
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 会员code. member_code
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员code", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 最后聊天时间. last_chat_time
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "最后聊天时间", name = "lastChatTime", required = false, example = "")
	private Date lastChatTime;
	/**
	 * 只读. 是否可用 1可用 0不可用. valid
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否可用 1可用 0不可用", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人name. create_user_name
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人name", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人name. modified_user_name
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人name", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改日期. modified_date
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改日期", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public Long getMbrChatTime() {
		return mbrChatTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setMbrChatTime(Long mbrChatTime) {
		this.mbrChatTime = mbrChatTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public Date getLastChatTime() {
		return lastChatTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setLastChatTime(Date lastChatTime) {
		this.lastChatTime = lastChatTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 14:26:30
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}
}

==> members-facade-2.0.1-20200228.144257-32-sources.jar: com/bizvane/members/facade/models/po/MbrChatTimePO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrChatTimePO implements Serializable {

	/**
	 * 只读. 主键. mbr_chat_time
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "主键", name = "mbrChatTime", required = false, example = "")
	private Long mbrChatTime;
	/**
	 * 只读. . sys_company_id
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. . brand_id
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 会员code. member_code
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员code", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 0未读 1已读. mark_read
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "0未读 1已读", name = "markRead", required = false, example = "")
	private Integer markRead;
	/**
	 * 只读. 最后聊天时间. last_chat_time
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "最后聊天时间", name = "lastChatTime", required = false, example = "")
	private Date lastChatTime;
	/**
	 * 只读. 是否可用 1可用 0不可用. valid
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否可用 1可用 0不可用", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人name. create_user_name
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人name", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人name. modified_user_name
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人name", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改日期. modified_date
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改日期", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Long getMbrChatTime() {
		return mbrChatTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setMbrChatTime(Long mbrChatTime) {
		this.mbrChatTime = mbrChatTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Integer getMarkRead() {
		return markRead;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setMarkRead(Integer markRead) {
		this.markRead = markRead;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Date getLastChatTime() {
		return lastChatTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setLastChatTime(Date lastChatTime) {
		this.lastChatTime = lastChatTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-05-30 18:12:52
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}
}
